summaryrefslogtreecommitdiffstats
path: root/kdejava/koala/org/kde/koala/KFilePlugin.java
diff options
context:
space:
mode:
Diffstat (limited to 'kdejava/koala/org/kde/koala/KFilePlugin.java')
-rw-r--r--kdejava/koala/org/kde/koala/KFilePlugin.java44
1 files changed, 22 insertions, 22 deletions
diff --git a/kdejava/koala/org/kde/koala/KFilePlugin.java b/kdejava/koala/org/kde/koala/KFilePlugin.java
index 0dd2ca43..b904fa38 100644
--- a/kdejava/koala/org/kde/koala/KFilePlugin.java
+++ b/kdejava/koala/org/kde/koala/KFilePlugin.java
@@ -2,11 +2,11 @@
package org.kde.koala;
import org.kde.qt.Qt;
-import org.kde.qt.QMetaObject;
+import org.kde.qt.TQMetaObject;
import org.kde.qt.QtSupport;
-import org.kde.qt.QObject;
-import org.kde.qt.QValidator;
-import org.kde.qt.QObject;
+import org.kde.qt.TQObject;
+import org.kde.qt.TQValidator;
+import org.kde.qt.TQObject;
/**
@@ -27,7 +27,7 @@ import org.kde.qt.QObject;
structure of the meta information supported by your plugin.
Example:
@code
- FooPlugin.FooPlugin(QObject parent, String name,
+ FooPlugin.FooPlugin(TQObject parent, String name,
ArrayListargs)
{
KFileMimeTypeInfo info = addMimeTypeInfo( "application/x-foo" );
@@ -36,11 +36,11 @@ import org.kde.qt.QObject;
group = addGroupInfo(info, "FooInfo", i18n("Foo Information"));
KFileMimeTypeInfo.ItemInfo item;
// our new items in the group
- item = addItemInfo(group, "Items", i18n("Items"), QVariant.Int);
- item = addItemInfo(group, "Size", i18n("Size"), QVariant.Int);
+ item = addItemInfo(group, "Items", i18n("Items"), TQVariant.Int);
+ item = addItemInfo(group, "Size", i18n("Size"), TQVariant.Int);
setUnit(item, KFileMimeTypeInfo.KiloBytes);
// strings are possible, too:
- //addItemInfo(group, "Document Type", i18n("Document type"), QVariant.String);
+ //addItemInfo(group, "Document Type", i18n("Document type"), TQVariant.String);
}
@endcode
Some meta information items are likely to be available in several different
@@ -55,7 +55,7 @@ import org.kde.qt.QObject;
achieve this task. This might be the best way for binary files, since a
change in the file format is likely to be supported by subsequent releases
of that library. Alternatively, for text-based file formats, you can use
- QTextStream to parse the file. For simple file formats, QRegExp can be of
+ TQTextStream to parse the file. For simple file formats, TQRegExp can be of
great help, too.
After you extracted the relevant information, use appendGroup() and
appendItem() to fill the meta information data structure (as defined in the
@@ -68,7 +68,7 @@ import org.kde.qt.QObject;
int numItems = 0;
int size = 0;
// do your calculations here, e.g. using a third-party
// library or by writing an own parser using e.g. QTextStream
// calculate numItems and size ...
// note: use the same key strings as in the constructor
KFileMetaInfoGroup group = appendGroup(info, "FooInfo");
@@ -79,8 +79,8 @@ import org.kde.qt.QObject;
@endcode
If you want to define mutable meta information items, you need to overwrite
the writeInfo() method. In this method, you can use third-party library
- (appropriate mostly for binary files, see above) or QTextStream to write the
- information back to the file. If you use QTextStream, be sure to write all
+ (appropriate mostly for binary files, see above) or TQTextStream to write the
+ information back to the file. If you use TQTextStream, be sure to write all
file contents back.
For some items, it might be that not all possible values are allowed. You
can overwrite the createValidator() method to define constraints for a meta
@@ -95,7 +95,7 @@ import org.kde.qt.QObject;
K_EXPORT_COMPONENT_FACTORY(kfile_foo, FooFactory("kfile_foo"));
@endcode
To make your plugin available within KDE, you also need to provide a
- <code>.desktop</code> file which describes your plugin. The required fields in the
+ <code>.desktop</code> file which describes your plugin. The retquired fields in the
file are:
- <code>Type</code>: must be @c "Service"
- <code>Name</code>: the name of the plugin
@@ -123,21 +123,21 @@ import org.kde.qt.QObject;
@short @brief Base class for a meta information plugin
*/
-public class KFilePlugin extends QObject {
+public class KFilePlugin extends TQObject {
protected KFilePlugin(Class dummy){super((Class) null);}
- public native QMetaObject metaObject();
+ public native TQMetaObject metaObject();
public native String className();
/**
Creates a new KFilePlugin instance. You need to implement a constructor
- with the same argument list as this is required by KGenericFactory
- @param parent the parent of the QObject, can be <code>0</code>
- @param name the name of the QObject, can be <code>0</code>
+ with the same argument list as this is retquired by KGenericFactory
+ @param parent the parent of the TQObject, can be <code>0</code>
+ @param name the name of the TQObject, can be <code>0</code>
@param args currently ignored
@short Creates a new KFilePlugin instance.
@see #addMimeTypeInfo
@see #addGroupInfo
@see #addItemInfo
- @see org.kde.qt.QObject
+ @see org.kde.qt.TQObject
*/
/**
Read the info from the file in this method and insert it into the
@@ -171,9 +171,9 @@ public class KFilePlugin extends QObject {
@param mimeType the mime type
@param group the group name of the validator item
@param key the key name of the validator item
- @param parent the QObject parent, can be <code>0</code>
- @param name the name of the QObject, can be <code>0</code>
+ @param parent the TQObject parent, can be <code>0</code>
+ @param name the name of the TQObject, can be <code>0</code>
@short This method should create an appropriate validator for the specified item if it's editable or return a null pointer if not.
*/
- public native QValidator createValidator(String mimeType, String group, String key, QObject parent, String name);
+ public native TQValidator createValidator(String mimeType, String group, String key, TQObject parent, String name);
}
@@ -68,7 +68,7 @@ import org.kde.qt.QObject;
int size = 0;
// do your calculations here, e.g. using a third-party
- // library or by writing an own parser using e.g. QTextStream
+ // library or by writing an own parser using e.g. TQTextStream
// calculate numItems and size ...
// note: use the same key strings as in the constructor